@@ -30,7 +30,7 @@ openapi_schema = {
                         "content": {"application/json": {"schema": {}}},
                     }
                 },
-                "summary": "Read Item Get",
+                "summary": "Read Item",
                 "operationId": "read_item_items__get",
             }
         }
